==> haskell-monad-journal-0.8.1-363-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-journal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 monad-journal
version:              0.8.1
visibility:           public
id:                   monad-journal-0.8.1-6Ji5CkZxRan5HmBxQPOn9Y
key:                  monad-journal-0.8.1-6Ji5CkZxRan5HmBxQPOn9Y
license:              BSD-3-Clause
maintainer:           Dimitri Sabadie <dimitri.sabadie@gmail.com>
author:               Dimitri Sabadie <dimitri.sabadie@gmail.com>
homepage:             http://github.com/phaazon/monad-journal
synopsis:             Pure logger typeclass and monad transformer
description:
    This package provides a typeclass for logging in
    pure code, or more generally, in any kind of
    context. You can do whatever you want with
    logs, especially get them, clear them or even
    sink them through '\''IO'\'' if you'\''re logging in
    @(MonadIO m) => m@.

category:             Control
abi:                  24a29b2e1b5e8dfff64a37e94d08bb8c
exposed:              True
exposed-modules:
    Control.Monad.Journal Control.Monad.Journal.Class
    Control.Monad.Trans.Journal

import-dirs:          /usr/lib/ghc-9.4.8/site-local/monad-journal-0.8.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/monad-journal-0.8.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/monad-journal-0.8.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monad-journal
hs-libraries:         HSmonad-journal-0.8.1-6Ji5CkZxRan5HmBxQPOn9Y
depends:
    base-4.17.2.1 monad-control-1.0.3.1-2wSm9gy3BOtBG8d4mpXdQq
    mtl-2.2.2 transformers-0.5.6.2
    transformers-base-0.4.6-BDjqv9wSWIKAPvuskfa65D

haddock-interfaces:
    /usr/share/doc/haskell-monad-journal/html/monad-journal.haddock

haddock-html:         /usr/share/doc/haskell-monad-journal/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-journal-0.8.1-364-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-journal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 monad-journal
version:              0.8.1
visibility:           public
id:                   monad-journal-0.8.1-2NCr51KgdcPKWnmC664wGo
key:                  monad-journal-0.8.1-2NCr51KgdcPKWnmC664wGo
license:              BSD-3-Clause
maintainer:           Dimitri Sabadie <dimitri.sabadie@gmail.com>
author:               Dimitri Sabadie <dimitri.sabadie@gmail.com>
homepage:             http://github.com/phaazon/monad-journal
synopsis:             Pure logger typeclass and monad transformer
description:
    This package provides a typeclass for logging in
    pure code, or more generally, in any kind of
    context. You can do whatever you want with
    logs, especially get them, clear them or even
    sink them through '\''IO'\'' if you'\''re logging in
    @(MonadIO m) => m@.

category:             Control
abi:                  81eab31ce37ce0883810168c97bbdb79
exposed:              True
exposed-modules:
    Control.Monad.Journal Control.Monad.Journal.Class
    Control.Monad.Trans.Journal

import-dirs:          /usr/lib/ghc-9.4.8/site-local/monad-journal-0.8.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/monad-journal-0.8.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/monad-journal-0.8.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monad-journal
hs-libraries:         HSmonad-journal-0.8.1-2NCr51KgdcPKWnmC664wGo
depends:
    base-4.17.2.1 monad-control-1.0.3.1-1uLiNwqbFdV8VlLjQHhhBl
    mtl-2.2.2 transformers-0.5.6.2
    transformers-base-0.4.6-8A6J7puCxi27yha2ploIhm

haddock-interfaces:
    /usr/share/doc/haskell-monad-journal/html/monad-journal.haddock

haddock-html:         /usr/share/doc/haskell-monad-journal/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
